@@ -38,6 +38,7 @@ tar_group_by <- function(
   packages = targets::tar_option_get("packages"),
   library = targets::tar_option_get("library"),
   format = targets::tar_option_get("format"),
+  repository = targets::tar_option_get("repository"),
   error = targets::tar_option_get("error"),
   memory = targets::tar_option_get("memory"),
   garbage_collection = targets::tar_option_get("garbage_collection"),
@@ -60,6 +61,7 @@ tar_group_by <- function(
     packages = packages,
     library = library,
     format = format,
+    repository = repository,
     iteration = "group",
     error = error,
     memory = memory,
